==> mx-menu-editor_19.5.tar.xz: mx-menu-editor-19.5/translations/mx-menu-editor_hr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="hr">
<context>
    <name>AddAppDialog</name>
    <message>
        <location filename="../addappdialog.ui" line="23"/>
        <source>Dialog</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../addappdialog.ui" line="33"/>
        <source>Categories</source>
        <translation>Kategorije</translation>
    </message>
    <message>
        <location filename="../addappdialog.ui" line="45"/>
        <source>Add category</source>
        <translation>Dodaj kategoriju</translation>
    </message>
    <message>
        <location filename="../addappdialog.ui" line="59"/>
        <source>Delete category</source>
        <translation>Izbriši kategoriju</translation>
    </message>
    <message>
        <location filename="../addappdialog.ui" line="76"/>
        <source>Command:</source>
        <translation>Naredba:</translation>
    </message>
    <message>
        <location filename="../addappdialog.ui" line="121"/>
        <source>Save Changes</source>
        <translation>Spremi izmjene</translation>
    </message>
    <message>
        <location filename="../addappdialog.ui" line="128"/>
        <source>Ctrl+S</source>
        <translation>Ctrl+S</translation>
    </message>
    <message>
        <location filename="../addappdialog.ui" line="166"/>
        <source>Quit dialog</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../addappdialog.ui" line="169"/>
        <location filename="../addappdialog.cpp" line="103"/>
        <source>Cancel</source>
        <translation>Otkaži</translation>
    </message>
    <message>
        <location filename="../addappdialog.ui" line="176"/>
        <source>Alt+N</source>
        <translation>Alt+N</translation>
    </message>
    <message>
        <location filename="../addappdialog.ui" line="194"/>
        <source>Select...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../addappdialog.ui" line="201"/>
        <source>Name:</source>
        <translation>Ime:</translation>
    </message>
    <message>
        <location filename="../addappdialog.ui" line="208"/>
        <source>Comment:</source>
        <translation>Komentar:</translation>
    </message>
    <message>
        <location filename="../addappdialog.ui" line="215"/>
        <source>Icon:</source>
        <translation>Ikona:</translation>
    </message>
    <message>
        <location filename="../addappdialog.ui" line="222"/>
        <location filename="../addappdialog.cpp" line="122"/>
        <source>Set icon</source>
        <translation>Postavi ikonu</translation>
    </message>
    <message>
        <location filename="../addappdialog.ui" line="235"/>
        <source>Run in Terminal</source>
        <translation>Pokreni u terminalu</translation>
    </message>
    <message>
        <location filename="../addappdialog.ui" line="248"/>
        <source>Startup Notifier</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../addappdialog.cpp" line="37"/>
        <source>Add Custom Application</source>
        <translation>Dodaj prilagođenu aplikaciju</translation>
    </message>
    <message>
        <location filename="../addappdialog.cpp" line="54"/>
        <source>Error</source>
        <translation>Greška</translation>
    </message>
    <message>
        <location filename="../addappdialog.cpp" line="54"/>
        <source>Could not save the file</source>
        <translation>Ne mogu spremiti datoteku</translation>
    </message>
    <message>
        <location filename="../addappdialog.cpp" line="103"/>
        <source>Save changes?</source>
        <translation>Spremiti izmjene?</translation>
    </message>
    <message>
        <location filename="../addappdialog.cpp" line="103"/>
        <source>Do you want to save your edits?</source>
        <translation>Želite li spremiti vaša uređivanja?</translation>
    </message>
    <message>
        <location filename="../addappdialog.cpp" line="103"/>
        <source>Save</source>
        <translation>Spremi</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.ui" line="17"/>
        <location filename="../mainwindow.cpp" line="839"/>
        <source>MX Menu Editor</source>
        <translation>MX uređivač izbornika</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="34"/>
        <source>Advanced Editor</source>
        <translation>Napredni uređivač</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="55"/>
        <source>Categories and applications</source>
        <translation>Kategorije i aplikacije</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="82"/>
        <source>Add custom application</source>
        <translation>Dodaj prilagođenu aplikaciju</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="96"/>
        <source>Options</source>
        <translation>Opcije</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="105"/>
        <source>Run in terminal</source>
        <translation>Pokreni u terminalu</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="115"/>
        <source>Hide</source>
        <translation>Sakrij</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="125"/>
        <source>Notify startup</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="148"/>
        <source>Quick Editor</source>
        <translation>Brzi uređivač</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="160"/>
        <source>Comment:</source>
        <translation>Komentar:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="170"/>
        <source>Restore original item</source>
        <translation>Obnovi izvornu stavku</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="181"/>
        <source>Command:</source>
        <translation>Naredba:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="191"/>
        <source>Select...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="205"/>
        <source>Name:</source>
        <translation>Ime:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="226"/>
        <source>Icon</source>
        <translation>Ikona</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="266"/>
        <location filename="../mainwindow.cpp" line="541"/>
        <source>Change icon</source>
        <translation>Promjeni ikonu</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="280"/>
        <source>Categories</source>
        <translation>Kategorije</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="292"/>
        <source>Add</source>
        <translation>Dodaj</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="306"/>
        <source>Delete</source>
        <translation>Izbriši</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="372"/>
        <source>Quit application</source>
        <translation>Zatvori aplikaciju</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="375"/>
        <source>Close</source>
        <translation>Zatvori</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="382"/>
        <source>Alt+N</source>
        <translation>Alt+N</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="423"/>
        <source>Display help</source>
        <translation>Prikaži pomoć</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="426"/>
        <source>Help</source>
        <translation>Pomoć</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="433"/>
        <source>Alt+H</source>
        <translation>Alt+H</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="452"/>
        <source>Save Changes</source>
        <translation>Spremi izmjene</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="459"/>
        <source>Ctrl+S</source>
        <translation>Ctrl+S</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="494"/>
        <source>About this application</source>
        <translation>O ovoj aplikaciji</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="497"/>
        <source>About...</source>
        <translation>O programu...</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="504"/>
        <source>Alt+B</source>
        <translation>Alt+B</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="462"/>
        <source>Select executable file</source>
        <translation>Odaberite izvršnu datoteku</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="525"/>
        <source>Image Files (*.png *.jpg *.bmp *.xpm)</source>
        <translation>Slikovne datoteke (*.png *.jpg *.bmp *.xpm)</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="718"/>
        <source>Choose category</source>
        <translation>Odaberite kategoriju</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="729"/>
        <location filename="../mainwindow.cpp" line="845"/>
        <location filename="../mainwindow.cpp" line="906"/>
        <source>Cancel</source>
        <translation>Otkaži</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="730"/>
        <source>OK</source>
        <translation>U redu</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="820"/>
        <source>Error</source>
        <translation>Greška</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="820"/>
        <source>Could not save the file</source>
        <translation>Ne mogu spremiti datoteku</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="838"/>
        <source>About MX Menu Editor</source>
        <translation>O MX uređivaču izbornika</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="839"/>
        <source>Version: </source>
        <translation>Inačica:</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="840"/>
        <source>Program for editing Xfce menu</source>
        <translation>Program za uređivanje Xfce izbornika</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="842"/>
        <source>Copyright (c) MX Linux</source>
        <translation>Autorska prava (c) MX Linux</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="843"/>
        <source>License</source>
        <translation>Licenca</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="844"/>
        <source>Changelog</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="860"/>
        <source>&amp;Close</source>
        <translation>&amp;Zatvori</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="906"/>
        <source>Save changes?</source>
        <translation>Spremiti izmjene?</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="906"/>
        <source>Do you want to save your edits?</source>
        <translation>Želite li spremiti vaša uređivanja?</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="906"/>
        <source>Save</source>
        <translation>Spremi</translation>
    </message>
</context>
<context>
    <name>QApplication</name>
    <message>
        <location filename="../main.cpp" line="51"/>
        <source>You must run this program as normal user.</source>
        <translation>Morate pokrenuti ovaj program kao normalni korisnik.</translation>
    </message>
</context>
</TS>

==> mx-menu-editor_21.7.01.tar.xz: mx-menu-editor-21.7.01/translations/mx-menu-editor_hr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="hr">
<context>
    <name>AddAppDialog</name>
    <message>
        <location filename="../addappdialog.ui" line="23"/>
        <source>Dialog</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../addappdialog.ui" line="33"/>
        <source>Categories</source>
        <translation>Kategorije</translation>
    </message>
    <message>
        <location filename="../addappdialog.ui" line="45"/>
        <source>Add category</source>
        <translation>Dodaj kategoriju</translation>
    </message>
    <message>
        <location filename="../addappdialog.ui" line="59"/>
        <source>Delete category</source>
        <translation>Izbriši kategoriju</translation>
    </message>
    <message>
        <location filename="../addappdialog.ui" line="76"/>
        <source>Command:</source>
        <translation>Naredba:</translation>
    </message>
    <message>
        <location filename="../addappdialog.ui" line="121"/>
        <source>Save Changes</source>
        <translation>Spremi izmjene</translation>
    </message>
    <message>
        <location filename="../addappdialog.ui" line="128"/>
        <source>Ctrl+S</source>
        <translation>Ctrl+S</translation>
    </message>
    <message>
        <location filename="../addappdialog.ui" line="166"/>
        <source>Quit dialog</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../addappdialog.ui" line="169"/>
        <source>Cancel</source>
        <translation>Otkaži</translation>
    </message>
    <message>
        <location filename="../addappdialog.ui" line="176"/>
        <source>Alt+N</source>
        <translation>Alt+N</translation>
    </message>
    <message>
        <location filename="../addappdialog.ui" line="194"/>
        <source>Select...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../addappdialog.ui" line="201"/>
        <source>Name:</source>
        <translation>Ime:</translation>
    </message>
    <message>
        <location filename="../addappdialog.ui" line="208"/>
        <source>Comment:</source>
        <translation>Komentar:</translation>
    </message>
    <message>
        <location filename="../addappdialog.ui" line="215"/>
        <source>Icon:</source>
        <translation>Ikona:</translation>
    </message>
    <message>
        <location filename="../addappdialog.ui" line="222"/>
        <location filename="../addappdialog.cpp" line="111"/>
        <source>Set icon</source>
        <translation>Postavi ikonu</translation>
    </message>
    <message>
        <location filename="../addappdialog.ui" line="235"/>
        <source>Run in Terminal</source>
        <translation>Pokreni u terminalu</translation>
    </message>
    <message>
        <location filename="../addappdialog.ui" line="248"/>
        <source>Startup Notifier</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../addappdialog.cpp" line="35"/>
        <source>Add Custom Application</source>
        <translation>Dodaj prilagođenu aplikaciju</translation>
    </message>
    <message>
        <location filename="../addappdialog.cpp" line="51"/>
        <source>Error</source>
        <translation>Greška</translation>
    </message>
    <message>
        <location filename="../addappdialog.cpp" line="51"/>
        <source>Could not save the file</source>
        <translation>Ne mogu spremiti datoteku</translation>
    </message>
    <message>
        <location filename="../addappdialog.cpp" line="93"/>
        <source>Save changes?</source>
        <translation>Spremiti izmjene?</translation>
    </message>
    <message>
        <location filename="../addappdialog.cpp" line="93"/>
        <source>Do you want to save your edits?</source>
        <translation>Želite li spremiti vaša uređivanja?</translation>
    </message>
    <message>
        <source>Save</source>
        <translation type="vanished">Spremi</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.ui" line="17"/>
        <location filename="../mainwindow.cpp" line="826"/>
        <source>MX Menu Editor</source>
        <translation>MX uređivač izbornika</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="34"/>
        <source>Advanced Editor</source>
        <translation>Napredni uređivač</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="55"/>
        <source>Categories and applications</source>
        <translation>Kategorije i aplikacije</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="82"/>
        <source>Add custom application</source>
        <translation>Dodaj prilagođenu aplikaciju</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="96"/>
        <source>Options</source>
        <translation>Opcije</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="105"/>
        <source>Run in terminal</source>
        <translation>Pokreni u terminalu</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="115"/>
        <source>Hide</source>
        <translation>Sakrij</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="125"/>
        <source>Notify startup</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="148"/>
        <source>Quick Editor</source>
        <translation>Brzi uređivač</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="160"/>
        <source>Comment:</source>
        <translation>Komentar:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="170"/>
        <source>Restore original item</source>
        <translation>Obnovi izvornu stavku</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="181"/>
        <source>Command:</source>
        <translation>Naredba:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="191"/>
        <source>Select...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="205"/>
        <source>Name:</source>
        <translation>Ime:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="226"/>
        <source>Icon</source>
        <translation>Ikona</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="266"/>
        <location filename="../mainwindow.cpp" line="519"/>
        <source>Change icon</source>
        <translation>Promjeni ikonu</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="280"/>
        <source>Categories</source>
        <translation>Kategorije</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="292"/>
        <source>Add</source>
        <translation>Dodaj</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="306"/>
        <source>Delete</source>
        <translation>Izbriši</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="372"/>
        <source>Quit application</source>
        <translation>Zatvori aplikaciju</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="375"/>
        <source>Close</source>
        <translation>Zatvori</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="382"/>
        <source>Alt+N</source>
        <translation>Alt+N</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="423"/>
        <source>Display help</source>
        <translation>Prikaži pomoć</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="426"/>
        <source>Help</source>
        <translation>Pomoć</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="433"/>
        <source>Alt+H</source>
        <translation>Alt+H</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="452"/>
        <source>Save Changes</source>
        <translation>Spremi izmjene</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="459"/>
        <source>Ctrl+S</source>
        <translation>Ctrl+S</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="494"/>
        <source>About this application</source>
        <translation>O ovoj aplikaciji</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="497"/>
        <source>About...</source>
        <translation>O programu...</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="504"/>
        <source>Alt+B</source>
        <translation>Alt+B</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="432"/>
        <source>Select executable file</source>
        <translation>Odaberite izvršnu datoteku</translation>
    </message>
    <message>
        <source>Image Files (*.png *.jpg *.bmp *.xpm)</source>
        <translation type="vanished">Slikovne datoteke (*.png *.jpg *.bmp *.xpm)</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="500"/>
        <source>Image Files (*.png *.jpg *.bmp *.xpm *.svg)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="700"/>
        <source>Choose category</source>
        <translation>Odaberite kategoriju</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="711"/>
        <location filename="../mainwindow.cpp" line="832"/>
        <source>Cancel</source>
        <translation>Otkaži</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="712"/>
        <source>OK</source>
        <translation>U redu</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="809"/>
        <source>Error</source>
        <translation>Greška</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="809"/>
        <source>Could not save the file</source>
        <translation>Ne mogu spremiti datoteku</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="825"/>
        <source>About MX Menu Editor</source>
        <translation>O MX uređivaču izbornika</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="826"/>
        <source>Version: </source>
        <translation>Inačica:</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="827"/>
        <source>Program for editing Xfce menu</source>
        <translation>Program za uređivanje Xfce izbornika</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="829"/>
        <source>Copyright (c) MX Linux</source>
        <translation>Autorska prava (c) MX Linux</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="830"/>
        <source>License</source>
        <translation>Licenca</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="831"/>
        <source>Changelog</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="847"/>
        <source>&amp;Close</source>
        <translation>&amp;Zatvori</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="892"/>
        <source>Save changes?</source>
        <translation>Spremiti izmjene?</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="893"/>
        <source>Do you want to save your edits?</source>
        <translation>Želite li spremiti vaša uređivanja?</translation>
    </message>
</context>
<context>
    <name>QApplication</name>
    <message>
        <location filename="../main.cpp" line="58"/>
        <source>You must run this program as normal user.</source>
        <translation>Morate pokrenuti ovaj program kao normalni korisnik.</translation>
    </message>
</context>
</TS>
